/* s_seq.h (sequence, implemented as doubly linked list or as array)

   Ambros Marzetta
   
 * $Source$
 * $Revision: 2732 $
 * $Date: 2000-11-15 12:14:52 -0400 (Wed, 15 Nov 2000) $
 * $Log$
 * Revision 1.2  2000/11/15 16:14:52  bremner
 * committing patched version of zram source
 *
 * Revision 1.1  1996/04/11  16:00:08  marzetta
 * Initial revision
 *
 */

#ifndef _S_SEQ_H_
#define _S_SEQ_H_
#include "z_base.h"		/* z_PtrProc */

/* Types ------------------------------------------------------------- */

typedef enum {s_seq_doublylinked, s_seq_numtypes} s_seq_typeT;
				/* different implementations */
#define s_seq_default s_seq_doublylinked	/* default implementation */

typedef struct s_seqT *s_seqP;	/* sequence */

typedef struct s_seq_refT *s_seq_refP; /* reference into a sequence */

#ifndef _S_SEQ_C_
typedef void *s_seq_elemP;	/* element of sequence */
#else /* _S_SEQ_C_ */
typedef struct s_seq_elemT *s_seq_elemP;	/* element of sequence */
#endif /* _S_SEQ_C_ */

/* Procedures -------------------------------------------------------- */

s_seqP s_seq_New(s_seq_typeT type);
/* Allocate an empty list. Choose an implementation
   of type type. */

void s_seq_Free(s_seqP l);
/* Deallocate the sequence l, which must be empty. */

s_seq_elemP s_seq_GetObject(s_seqP l, s_seq_refP where);
/* Retrieve the object referenced by where. */

s_seq_refP s_seq_InsertFirst(s_seqP l, s_seq_elemP x);
/* Insert x into the sequence l (at the beginning). */

s_seq_refP s_seq_InsertLast(s_seqP l, s_seq_elemP x);
/* Insert x into the sequence l (at the end). */

s_seq_refP s_seq_InsertAfter(s_seqP l, s_seq_refP r, s_seq_elemP x);
/* Insert x into the sequence l after r. */

long s_seq_numElements(s_seqP l);
/* Return the number of elements in l. */

s_seq_refP s_seq_First(s_seqP l);
/* Return a reference to the first element of the sequence.
   The sequence must not be empty. */

s_seq_refP s_seq_Last(s_seqP l);
/* Return a reference to the last element of the sequence.
   The sequence must not be empty. */

void s_seq_Delete(s_seqP l, s_seq_refP ref);
/* Delete the element referenced by ref. */

void s_seq_ForAll(s_seqP l, z_PtrProc whatToDo);
/* Call whatToDo for all elements of the sequence. WhatToDo must not
   access the sequence. */

#endif /* _S_SEQ_H_ */
