/* z_md_seq.c (parallel base functions: machine dependent part)
                (Sequential version)

   Ambros Marzetta
   95-04-21

 * $Source$
 * $Revision: 3145 $
 * $Date: 2004-08-25 18:01:45 -0300 (Wed, 25 Aug 2004) $
 * $Log$
 * Revision 1.3  2004/08/25 21:01:45  bremner
 * libutil configuration
 * zram without mpi
 *
 * Revision 1.2  2000/11/15 16:14:52  bremner
 *
 * committing patched version of zram source
 *
 * Revision 1.5  1996/04/09  13:26:39  marzetta
 * Added SEQUENTIAL
 *
 * Revision 1.4  1995/08/22  12:39:45  marzetta
 * New message passing, MPI
 *
 * Revision 1.3  1995/08/15  08:56:40  marzetta
 * Collect jobs
 *
 * Revision 1.2  1995/08/03  08:56:13  marzetta
 * Macintosh portability
 *
 * Revision 1.1  1995/07/28  08:36:56  marzetta
 * Initial revision
 *
 * Revision 1.1  1995/07/27  11:36:00  marzetta
 * Separation of message passing interface
 *
 */

#include <string.h>		/* memcpy() */
#include <stdlib.h>		/* abort() */
#include "z_md.h"
#include "z_par_intern.h"

const boolean z_md_doesTD = 1;

#define Mega 1000000

long z_memsize = 90 * Mega;	/* nobi / tobi: 128 MByte real memory */
long z_memavail = 90 * Mega;	/* nobi / tobi: 128 MByte real memory */

/* Send / Receive ------------------------------------------------ */
#ifndef SEQUENTIAL

#ifndef BUFSIZE
#define BUFSIZE 100000
#endif
/* const long z_bufunits = BUFSIZE; */

boolean z_md_TestSend(void)
{
  /* (PE only) Is it possible to overwrite outbuffer? */
  return 1;			/* broadcast is always possible */
} /* z_md_TestSend */

void z_md_Isend(struct buffer *buffer, long size,
		 int dest, const char *comment)
{
  /* Send outbuffer to dest*/
  assert(0);			/* a single processor never can send */
} /* z_md_Isend */

void z_md_Ibroadcast(struct buffer *buffer, long size, const char *comment)
{
  /* Broadcast outbuffer */
} /* z_md_Ibroadcast */

/* Starting jobs ---------------------------------------------------- */

void z_md_StartParallel()
{
  /* Broadcast outbuffer and initiate the parallel computation. */
} /* z_md_StartParallel */

void z_md_Wait(z_ResultProc resultProc)
{
  /* There is nothing to wait for */
} /* z_md_Wait */

void z_md_SendToFE(boolean collect)
{
  assert(0);
} /* z_md_SendToFE */

void z_md_RecBuffer(void)
{
  assert(0);			/* not used */
} /* z_md_RecBuffer */

void z_md_Irecv(void)
{
  /* do nothing */
} /* z_md_Irecv */

boolean z_md_TestRecv(void)
{
  return 0;			/* a single processor never gets messages */
} /* z_md_TestRecv */

boolean z_md_WaitRecv(void)
/* The processing element is idle. 
   Wait for the receive operation started by z_StartReceive to complete.
   Return true if/when all processing elements are idle.
   Return false if/when a message is received.
   */
{
  return 1;
} /* z_md_WaitRecv */

#endif /* SEQUENTIAL */
/* Assert ---------------------------------------------------------- */

void z_md_abort(void)
{
#ifdef macintosh
  exit(1);
#else
  abort();
#endif /* macintosh */
} /* z_assert */

/* Initialization --------------------------------------------------- */

void z_md_Init(int *argc, char ***argv)
/* Initialize this module. Called by main(). */
{
  z_buf_alloc(BUFSIZE);
  z_par_Init(0, 1, 1);		/* sequential */
} /* z_md_Init */

void z_md_Fin(void)
/* Called my main() */
{
} /* z_md_Fin */
