/* z_spq.h (speculative priority queues)

   Ambros Marzetta

 * $Source$
 * $Revision: 2732 $
 * $Date: 2000-11-15 12:14:52 -0400 (Wed, 15 Nov 2000) $
 * $Log$
 * Revision 1.2  2000/11/15 16:14:52  bremner
 * committing patched version of zram source
 *
 * Revision 1.3  1996/04/09  13:23:25  marzetta
 * Added SEQUENTIAL and some comments
 *
 */

#ifndef _Z_SPQ_H_
#define _Z_SPQ_H_
#include "s_pq.h"

/* Types ------------------------------------------------------------- */

typedef struct z_spqT *z_spqP;	/* speculative priority queue */

/* Procedures -------------------------------------------------------- */

z_spqP z_spq_NewSpeculativePriorityQueue(z_pq_CompProcP compare);
/* Allocate an empty speculative priority queue. This procedure must be
   called on all processors at the same time. */

void z_spq_FreeSpeculativePriorityQueue(z_spqP pq);
/* Deallocate the speculative priority queue pq, which must be empty.
   This procedure must be called on all processors at the same time. */

void z_spq_Insert(z_spqP pq, z_NodeP x);
/* Insert x into the speculative priority queue. */

z_NodeP z_spq_GetDeleteNearMinimum(z_spqP pq);
/* Retrieve an element near the minimum and delete it. Return NULL if the
   speculative queue is empty (this uses the termination detection algorithm
   from z_mp.h). */

long z_spq_numLocalElements(z_spqP pq);
/* Return the number of elements in the local part of pq. */

void z_spq_DeleteLocalAbove(z_spqP pq, z_NodeP upperBound,
			    whatToDoProcP whatToDo);
/* Remove all elements >= upperBound from the priority queue. Call
   whatToDo for each of them. WhatToDo must not access the priority
   queue, but should e.g. deallocate the elements. */

char *z_spq_InfoString(z_spqP pq);
/* Return statistical information about the queue. This is a static string. */

void z_spq_init(void);

/* Elements of the speculative priority queue must be z_NodeP. Their size
   is used to transfer them to other processors. They are deallocated by
   z_FreeNode().

   The speculative priority queue uses the termination detection algorithm
   from z_mp.h. The application must call z_StartMessagePassing() before
   the first operation on the spq.
   
   In the current implementation, only one speculative priority queue may
   be allocated at the same time.
   */

#endif /* _Z_SPQ_H_ */

